d = \
{
    "_personal state": [
        "_physical personal state",
        "_emotional personal state"
    ],
    "_physical personal state": [
        "hungry",
        "tire",
        "sore",
        "injured",
        "hurt",
        "recovering",
        "thirsty",
        "hot",
        "cold",
        "sick"
    ],
    "_emotional personal state":[
        "_negative state",
        "_positive state",
        "_neutral state"
    ],

    "_negative state": [
        "_feelings neg",
        "_downers"
    ],
    "_positive state": [
        "_feelings pos",
        "_uppers"
    ],
    "_downers": [
        "death",
        "lost",
        "broken",
        "fired",
        "divorced",
        "divorce",
        "died",
        "injured",
        "dying",
        "injury",
        "broke",
        "imprisoned",
        "hurt",
        "die"
    ],
    "_uppers": [
        "fun",
        "promote",
        "marry",
        "new baby",
        "a raise",
        "married",
        "birth",
        "marriage",
        "promotion"
    ],
    "_feelings neg": [
        "terrible",
        "horrible",
        "worried",
        "annoyed",
        "insane",
        "awful",
        "disgusted",
        "crazy",
        "confused",
        "tired",
        "sad",
        "stressful",
        "bothered",
        "fearful",
        "stressed",
        "depressed",
        "stress",
        "down",
        "dumps",
        "bad",
        "grumpy",
        "nervous",
        "anxious",
        "lonely",
        "scared",
        "been better",
        "pooped",
        "poopy",
        "like poop",
        "tired",
        "exhausted",
        "crampy",
        "overwhelmed",
        "distraught",
        "crappy",
        "like crap",
        "angry",
        "mad",
        "furious",
        "afraid",
        "unfortunate",
        "pessimistic",
        "nosy",
        "snoopy",
        "rebellious",
        "hateful",
        "upset",
        "enraged",
        "bitter",
        "jaded",
        "unpleasant",
        "hostile",
        "insulted",
        "irritated",
        "disappointed",
        "discouraged",
        "disheartened",
        "ashamed",
        "powerless",
        "guilty",
        "miserable",
        "dissatisfied",
        "doubtful",
        "uncertain",
        "indecisive",
        "perplexed",
        "embarrased",
        "hesitant",
        "stupified",
        "disillusioned",
        "unbelieving",
        "skeptical",
        "distrustful",
        "misgiving",
        "lost",
        "uneasy",
        "tense",
        "vulnerable",
        "fatigued",
        "useless",
        "pathetic",
        "distressed",
        "frustrated",
        "worked up",
        "fuming",
        "infuriated",
        "desperate",
        "weary",
        "bored",
        "disinterested",
        "terrified",
        "panic",
        "alarmed",
        "suspicious",
        "restless",
        "dejected",
        "rejected",
        "heartbroken",
        "agonized",
        "appalled",
        "humiliated",
        "wronged",
        "alienated",
        "grief",
        "unhappy"
    ],
    "_feelings pos": [
        "well",
        "happy",
        "cheerful",
        "fantastic",
        "excited",
        "ready",
        "joyful",
        "cheery",
        "wonderful",
        "great",
        "thrilled",
        "good",
        "joy",
        "upbeat",
        "swell",
        "lucky",
        "fortunate",
        "delighted",
        "thankful",
        "glad",
        "elated",
        "important",
        "festive",
        "ecstatic",
        "satisfied",
        "proud",
        "amazed",
        "confident",
        "sympathetic",
        "kind",
        "accepting",
        "brave",
        "courageous",
        "loving",
        "energetic",
        "optimistic",
        "thrilled",
        "calm",
        "peaceful",
        "pease",
        "at ease",
        "comfortable",
        "pleased",
        "encouraged",
        "clever",
        "content",
        "relaxed",
        "serene",
        "blessed",
        "reassured",
        "passionate",
        "comforted",
        "loved",
        "inquisitive",
        "engrossed",
        "curious",
        "determined",
        "hopeful",
        "daring",
        "bold",
        "inspired",
        "secure",
        "safe",
        "unique",
        "enthusiastic"
    ],
    "_neutral state": [
        "okay",
        "ok",
        "fine",
        "alright",
        "surprised",
        "impulsive"
    ],
    "_gender": ["female", "male"],
    "female": ["wife", "daughter", "sister", "aunt", "grandmother", "niece", "girlfriend", "mother"],
    "male": ["husband", "son", "brother", "uncle", "grandfather", "nephew", "boyfriend", "father"],
    "_related person": ["partner", "roommate", "friend", "colleague", "family"],
    "partner": ["spouse", "_romantic partner", "boyfriend", "girlfriend"],
    "spouse": ["husband", "wife"],
    "parent": ["mother", "father"],
    "family": ["parent", "relative", "child", "sibling", "inlaw"],
    "grandparent": ["grandmother", "grandfather"],
    "child": ["son", "daughter"],
    "sibling": ["brother", "sister"],
    "relative": ["aunt", "uncle", "grandparent", "niece", "nephew", "cousin"],
    "inlaw": ["father in law", "mother in law", "sister in law", "brother in law", "daughter in law", "son in law"],

    "_old_life events": [
        "_romantic event",
        "_end romantic event",
        "_new life",
        "_end life",
        "_relocate",
        "_new job",
        "_end job",
        "illness",
        "graduation",
        "vacation",
        "birthday",
        "award",
        "admission",
        "exam",
        "_better job",
        "surgery",
        "_child development"
    ],

    "_romantic event": [
        "wedding",
        "marriage",
        "asked out",
        "dating",
        "proposal",
        "engagement",
        "new partner",
        "new relationship",
        "in a relationship",
        "first kiss",
        "move in together"
    ],

    "_end romantic event": [
        "dump",
        "divorce",
        "separation",
        "breaking off",
        "cheat"
    ],

    "_new life": [
        "birth",
        "labor",
        "adoption",
        "baby",
        "newborn",
        "baptism",
        "pregnancy"
    ],

    "_end life": [
        "death",
        "suicide",
        "murder"
    ],

    "_relocate": [
        "relocation",
        "moved",
        "bought a house"
    ],

    "_new job": [
        "new job",
        "hire",
        "start up",
        "internship",
        "intern",
        "interview"
    ],

    "_better job": [
        "raise",
        "promotion",
        "bonus"
    ],

    "_end job": [
        "fired",
        "quit",
        "furloughed"
    ],

    "illness": [
        "_physical illness",
        "mental illness",
        "hospital",
        "emergency room"
    ],

    "_physical illness": [
        "cancer",
        "stroke",
        "heart attack"
    ],

    "mental illness":[
        "alzheimers",
        "dementia"
    ],

    "graduation": [
        "phd"
    ],

    "_child development": [
        "walk",
        "first step",
        "talk",
        "first word",
        "pottytrain",
        "crawling",
        "laughing",
        "smiling",
        "first day of school",
        "kindergarten",
        "reading",
        "writing",
        "license",
        "driving"
    ],

    "_relationship state":[
        "_pos relationship",
        "_neg relationship"
    ],

    "_pos relationship": [
        "hold hands",
        "tickle",
        "kiss",
        "laugh",
        "smile",
        "play",
        "talk"
    ],

    "_neg relationship": [
        "cry",
        "fight",
        "argue",
        "argument",
        "abuse",
        "namecall",
        "bully",
        "nag",
        "make fun of",
        "oppress",
        "intimidate",
        "dominate",
        "lie",
        "rumor",
        "therapy",
        "counseling",
        "ignore",
        "neglect",
        "avoid"
    ],
    "body": [
        "arm",
        "leg",
        "torso",
        "foot",
        "hand",
        "head",
        "eye",
        "ear",
        "mouth",
        "nose",
        "hair",
        "finger",
        "toe",
        "nail",
        "knee",
        "elbow",
        "wrist",
        "neck"
    ],

    "_sensitive body":[
        "vagina",
        "penis",
        "butt"
    ],

    "_religion": [
        "Christianity",
        "Islam",
        "atheism",
        "agnostic"
        "Hinduism",
        "Chinese",
        "Buddhism",
        "primal",
        "African",
        "Sikhism",
        "Juche",
        "Spiritism",
        "Judaism",
        "Bahai",
        "Jainism",
        "Shinto",
        "Cao Dai",
        "Zoroastrianism",
        "Tenrikyo",
        "Neo Paganism",
        "Universalism"
    ],

    "christianity":[
        "catholic",
        "lutheran",
        "protestant",
        "anglican",
        "orthodox",
        "assyrian"
    ],

    "_number":[
        "one",
        "two",
        "three",
        "four",
        "five",
        "six",
        "seven",
        "eight",
        "nine",
        "ten",
        "eleven",
        "twelve",
        "thirteen",
        "fourteen",
        "fifteen",
        "sixteen",
        "seventeen",
        "eighteen",
        "nineteen",
        "twenty",
        "twentyone"
    ],

    "_age":[
        "_number",
        "twenties",
        "thirties",
        "forties",
        "fifties",
        "sixties",
        "seventies",
        "eighties",
        "nineties",
        "one hundred"
    ],

    "_job status":[
        "employed",
        "unemployed",
        "retired",
        "fired",
        "furloughed"
    ],

    "_romantic status":[
        "married",
        "divorced",
        "separated",
        "widowed",
        "engaged",
        "single",
        "dating"
    ],

    "_living status":[
        "with parents",
        "on my own",
        "roommate",
        "dorm"
    ],

    "_education status":[
        "elementary school",
        "middle school",
        "high school",
        "university",
        "undergraduate",
        "graduate student",
        "masters",
        "phd",
        "postdoc",
        "degree",
        "dropout"
    ],

    "_political figures":[
        "obama",
        "trump",
        "biden",
        "pence",
        "clinton",
        "cruz",
        "sanders",
        "warren",
        "bush",
        "pelosi",
        "harris",
        "cortez",
        "palin",
        "yang"
    ],

    "celebrity":[
        "cristiano ronaldo",
        "lionel messi",
        "neymar",
        "ariana grande",
        "dwayne johnson",
        "the rock",
        "selena gomez",
        "kylie jenner",
        "kendall jenner",
        "kardashian",
        "beyonce",
        "rihanna",
        "taylor swift",
        "justin bieber",
        "nicki minaj",
        "jennifer lopez",
        "jennifer aniston",
        "lebron james",
        "miley cyrus",
        "katy perry",
        "kevin hart",
        "ellen degeneres",
        "oprah",
        "demi lovato",
        "zendaya",
        "tom holland",
        "chris evans",
        "hemsworth",
        "drake",
        "lady gaga"
    ],

    "political affiliation":[
        "democrat",
        "republican",
        "independent",
        "liberal",
        "conservative"
    ],

    "sexual orientation":[
        "straight",
        "homosexual",
        "bisexual",
        "asexual",
        "transgender",
        "nonbinary"
    ],

    "activity":[
        "chore",
        "errand",
        "hobby",
        "exercise",
        "outdoor destination",
        "indoor destination",
        "gaming",
        "video platform",
        "children activity",
        "routine"
    ],
    "chore":[
        "clean",
        "mow",
        "yardwork"
    ],
    "clean":[
        "vacuum",
        "sweep",
        "dust",
        "wipe",
        "scrub",
        "wash",
        "fold",
        "laundry",
        "organize",
        "dish",
        "unload",
        "reload",
        "dishwasher",
        "washer",
        "dryer"
    ],
    "errand":[
        "store",
        "bank",
        "cleaners",
        "post office"
    ],
    "hobby":[
        "cook",
        "program",
        "write",
        "read",
        "pottery",
        "pool",
        "board games",
        "bowl",
        "draw",
        "color",
        "sing",
        "fish",
        "garden",
        "plant",
        "meditate",
        "bake",
        "paint"
    ],
    "exercise":[
        "outdoor exercise",
        "indoor exercise",
        "sports"
    ],
    "outdoor exercise":[
        "run",
        "walk",
        "hike",
        "bike",
        "jog"
    ],
    "indoor exercise":[
        "dance",
        "pilates",
        "yoga",
        "weight"
    ],
    "sports":[
        "soccer",
        "football",
        "baseball",
        "basketball",
        "volleyball",
        "tennis",
        "ping pong",
        "cricket",
        "hockey"
    ],
    "outdoor destination":[
        "park",
        "festival",
        "concert",
        "pool",
        "waterpark",
        "garden"
    ],
    "indoor destination":[
        "appointment",
        "library",
        "mall",
        "appointment",
        "museum",
        "arcade",
        "restaurant",
        "theatre"
    ],
    "appointment":[
        "dentist",
        "doctor"
    ],
    "gaming":[
        "game console",
        "vgame"
    ],
    "game console":[
        "nintendo switch",
        "playstation",
        "xbox",
        "game cube",
        "nintendo ds",
        "wii",
        "pc",
        "game boy",
        "ipad",
        "tablet"
    ],
    "vgame":[
        "minecraft",
        "fortnite",
        "overwatch",
        "pokemon",
        "supersonic",
        "halo"
    ],
    "video platform":[
        "television",
        "youtube",
        "netflix",
        "hulu",
        "hbo"
    ],
    "children activity":[
        "barbie",
        "house",
        "doctor",
        "stuffed animals",
        "stuffed animal"
    ],
    "routine":[
        "_day start",
        "_day end",
        "_beauty activity",
        "skincare"
    ],
    "_beauty activity":[
        "blowdry",
        "brush",
        "style hair",
        "makeup",
        "nail"
    ],
    "skincare":[
        "cream",
        "serum",
        "oil"
    ],
    "makeup":[
        "foundation",
        "blush",
        "bronzer",
        "contour",
        "highlighter",
        "powder",
        "mascara",
        "eyeliner",
        "lipstick",
        "lipgloss",
        "eyeshadow",
        "eyebrow",
        "concealer",
        "setting spray",
        "primer",
        "brush"
    ],
    "_day start":[
        "wake up",
        "brush teeth",
        "breakfast",
        "dressed",
        "getting ready",
        "shower",
        "make bed",
        "deodorant",
        "perfume",
        "cologne",
        "lotion",
        "spray",
        "shave",
        "_beauty activity",
        "skincare",
        "coffee"
    ],
    "_day end":[
        "sleep",
        "remove makeup",
        "medicine",
        "brush teeth",
        "dinner",
        "dessert",
        "shower",
        "pajamas"
    ],
    "_insults":[
        "bitch",
        "shit",
        "shitty",
        "dumb",
        "stupid",
        "idiotic",
        "idiot",
        "annoying",
        "frustrating",
        "retarded",
        "imbecile",
        "irritating",
        "infuriating",
        "exasperating",
        "maddening",
        "tiresome",
        "horrible",
        "worst",
        "garbage",
        "worthless",
        "useless"
    ]
}

e = \
{
    "like": ["love", "want", "desire"],

    "boyfriend": ["boyfriend", "boy friend"],
    "girlfriend": ["girlfriend", "girl friend"],
    "_romantic partner": ["lover", "significant other"],
    "roommate": ["roommate", "roomate", "room mate"],
    "mother": ["mother", "mom", "ma", "mama", "mommy"],
    "father": ["father", "dad", "pa", "papa", "daddy"],
    "child": ["kid", "kiddo", "offspring", "child"],
    "son": ["son", "boy"],
    "daughter": ["daughter", "girl"],
    "grandfather": ["grandpa"],
    "grandmother": ["grandma"],

    "smart": ["smart", "intelligent", "bright", "capable", "sharp"],
    "funny": ["funny", "humorous", "clever", "witty", "hilarious", "joker", "jokester"],
    "outgoing": ["outgoing", "extraverted", "sociable", "social", "friendly", "warm"],
    "shy": ["shy", "intraverted", "guarded", "loner"],
    "polite": ["polite", "manners", "decent"],
    "conceited": ["conceited", "overconfident", "arrogant", "full of", "narcissistic", "egotistic", "egotistical",
                  "selfish"],
    "beautiful": ["gorgeous", "pretty", "hot", "sexy"],

    "death": ["passed away","die"],
    "fired": ["let go", "laid off"],
    "marriage": ["marry"],
    "engagement": ["engage"],
    "proposal": ["propose"],
    "separation": ["separate"],
    "vacation": ["trip", "travel"],
    "adoption": ["adopt"],
    "baptism": ["baptize"],
    "relocation": ["relocate"],
    "alzheimers": ["alzheimer"],
    "award": ["certificate", "trophy", "ribbon", "scholarship", "prize", "fellowship"],
    "admission": ["admit", "accept"],
    "exams": ["test", "final", "midterm", "s a t", "a c t", "m c a t", "l s a t", "bar exam"],
    "graduation": ["graduate", "diploma"],
    "phd": ["dissertation", "thesis", "defense"],
    "emergency room": ["e r"],
    "promotion": ["promote"],
    "pottytrain": ["potty train", "potty training", "potty trained"],
    "pregnancy": ["pregnant", "expecting"],
    "colleague": ["coworker","co worker", "boss", "supervisor", "manager", "peer"],
    "tire": ["exhaust","sleep"],
    "hot": ["warm"],
    "cold": ["chilly", "freezing"],
    "sick": ["ill", "unwell", "under the weather"],

    "hold hands": ["holding hands"],
    "kiss": ["make out", "makeout"],
    "namecall": ["name call", "namecalling", "name calling"],
    "bully": ["torment","tyrannize"],
    "make fun of": ["taunt", "tease", "mock", "ridicule"],
    "fight": ["beat"],
    "argue": ["yell", "scream", "shout"],

    "torso": ["abdomen", "upper body", "chest"],
    "vagina": ["pussy"],
    "penis": ["dick", "cock"],
    "butt": ["ass","asshole"],
    "nail": ["toenail", "fingernail"],

    "primal": ["indigenous"],
    "universalism": ["unitarian"],
    "christianity": ["christian"],
    "islam": ["muslim"],
    "hinduism": ["hindu"],
    "buddhism": ["buddhist"],
    "judaism": ["jew"],
    "atheism": ["atheist"],

    "twentyone": ["twenty one"],

    "united states": ["u s"],

    "with parents": ["in parents"],
    "dorm": ["residence hall", "residence halls", "college", "university"],

    "university": ["college"],
    "graduate student": ["graduate school"],

    "straight": ["heterosexual"],
    "homosexual": ["gay", "lesbian"],
    "bisexual": ["bi"],
    "transgender": ["trans"],
    "nonbinary": ["non binary"],

    "sleep": ["doze","nap","siesta","asleep","to bed"],
    "homework": ["assignment","presentation","test","quiz","flashcards","study","paper","report","project","schoolwork","school work"],
    "class": ["lecture"],
    "job": ["work","office"],
    "theatre": ["theater","cinema","movies"],
    "store": ["shop"],
    "nintendo switch": ["switch"],
    "playstation": ["ps", "p s"],
    "nintendo ds": ["ds", "d s"],
    "wii": ["oui", "we"],
    "pc": ["computer","laptop"],
    "television": ["tv", "t v", "telly"],
    "hbo": ["h b o"],
    "barbie": ["barbies"],
    "soccer": ["european football", "assocation football"],
    "genitalia": ["penis","dick","cock","meat","vagina","pussy","cunt","twat"],
    "sex": ["lovemaking"],
    "exercise": ["workout", "work out"],
    "travel": ["run","go","drive","walk"],
    "wake up":["woke up", "out of bed", "waking up", "got up", "getting up"],
    "brush teeth": ["brushed teeth", "brushing teeth", "floss teeth", "flossing teeth"],
    "dressed": ["clothes", "clothing"],
    "getting ready": ["got ready"],
    "shower": ["bathe", "wash", "bath"],
    "make bed": ["made bed", "making bed", "sheet"],
    "blowdry": ["blow dry"],
    "brush": ["comb"],
    "style hair": ["did hair", "do hair", "doing hair"],
    "remove makeup": ["removed makeup", "take off makeup", "took off makeup",
                      "makeup remover", "wipe off makeup", "wiped off makeup"],
    "medicine": ["pill"],
    "pajamas": ["pj","pjs","nightgown"]


}